@@ -293,46 +293,33 @@ def check_valid_fs_license(lic=None):
     """
     Run ``mri_convert`` to assess FreeSurfer access to a license.
 
-    Parameters
-    ----------
-    lic : :obj:`str`, optional
-        Path to FreeSurfer license file
-
     Returns
     -------
     valid : :obj:`bool`
-        FreeSurfer license is valid
+        FreeSurfer successfully executed (valid license)
 
     """
     from pathlib import Path
     import subprocess as sp
     from tempfile import TemporaryDirectory
-
-    import nibabel as nb
-    import numpy as np
+    from pkg_resources import resource_filename
 
     if lic is not None:
-        import os
-
-        os.environ["FS_LICENSE"] = str(Path(lic).absolute())
+        import warnings
+        warnings.warn("The license argument has been deprecated, has no effect, and will be "
+                      "removed in 1.3.0. Please set the environment if needed before calling "
+                      "this function without arguments.",
+                      DeprecationWarning)
 
     with TemporaryDirectory() as tmpdir:
-        nii_file = str(Path(tmpdir) / "test.nii.gz")
-        out_file = str(Path(tmpdir) / "out.mgz")
-        # create test NIfTI
-        nb.Nifti1Image(np.zeros((5, 5, 5)), np.eye(4)).to_filename(nii_file)
         # quick FreeSurfer command
         _cmd = (
             "mri_convert",
-            "--out_type",
-            "mgz",
-            "--input_volume",
-            nii_file,
-            "--output_volume",
-            out_file,
+            resource_filename("niworkflows", "data/sentinel.nii.gz"),
+            str(Path(tmpdir) / "out.mgz"),
         )
-        proc = sp.run(_cmd, stdout=sp.PIPE, stderr=sp.PIPE)
-    return "ERROR: FreeSurfer license file" not in proc.stderr.decode()
+        proc = sp.run(_cmd, stdout=sp.PIPE, stderr=sp.STDOUT)
+    return proc.returncode == 0 and "ERROR:" not in proc.stdout.decode()
 
 
 if __name__ == "__main__":
